==> odps-center-api-1.1.79-20231017.031658-3-sources.jar: cn/com/duiba/odps/center/api/dto/hsbc/DuibaPartnerActJoinDetailNewDTO.java <==
package cn.com.duiba.odps.center.api.dto.hsbc;

import java.io.Serializable;
import java.util.Date;

/**
 * @author: LuHui
 * @date: 2023/10/16 17:57
 * @description:
 */
public class DuibaPartnerActJoinDetailNewDTO implements Serializable {
    private static final long serialVersionUID = 9156092594387363418L;

    /**
     * 自增主键
     */
    private Long id;

    /**
     * 应用ID
     */
    private String appId;
    /**
     * 兑吧活动id
     */
    private String duibaActivityId;
    /**
     * 开发者活动ID
     */
    private String operatingActivityId;
    /**
     * 活动名称
     */
    private String activityName;
    /**
     * 活动开始时间
     */
    private Date activityStartTime;
    /**
     * 活动结束时间
     */
    private Date activityEndTime;
    /**
     * 开发者ID
     */
    private String partnerUserId;
    /**
     * 兑吧用户ID
     */
    private Long consumerId;

    private Long consumerCredits;

    /**
     * 消耗积分数
     */
    private Long consumeCredits;

    /**
     * 中奖奖品id
     */
    private String activityOptionId;

    /**
     * 中奖奖品名称
     */
    private String activityOptionName;
    /**
     * 领奖状态
     */
    private Integer acceptStatus;
    /**
     * 参与时间
     */
    private Date joinTime;
    /**
     * 参与流水ID
     */
    private Long joinFlowId;
    /**
     * 任务名称
     */
    private String taskName;
    /**
     * 完成次数
     */
    private Long completeTimes;
    /**
     * 消费次数
     */
    private Long consumeTimes;

    /**
     * 创建时间
     */
    private Date gmtCreate;

    /**
     * 修改时间
     */
    private Date gmtModified;


    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getAppId() {
        return appId;
    }

    public void setAppId(String appId) {
        this.appId = appId;
    }

    public String getDuibaActivityId() {
        return duibaActivityId;
    }

    public void setDuibaActivityId(String duibaActivityId) {
        this.duibaActivityId = duibaActivityId;
    }

    public String getOperatingActivityId() {
        return operatingActivityId;
    }

    public void setOperatingActivityId(String operatingActivityId) {
        this.operatingActivityId = operatingActivityId;
    }

    public String getActivityName() {
        return activityName;
    }

    public void setActivityName(String activityName) {
        this.activityName = activityName;
    }

    public Date getActivityStartTime() {
        return activityStartTime;
    }

    public void setActivityStartTime(Date activityStartTime) {
        this.activityStartTime = activityStartTime;
    }

    public Date getActivityEndTime() {
        return activityEndTime;
    }

    public void setActivityEndTime(Date activityEndTime) {
        this.activityEndTime = activityEndTime;
    }

    public String getPartnerUserId() {
        return partnerUserId;
    }

    public void setPartnerUserId(String partnerUserId) {
        this.partnerUserId = partnerUserId;
    }

    public Long getConsumerId() {
        return consumerId;
    }

    public void setConsumerId(Long consumerId) {
        this.consumerId = consumerId;
    }

    public Long getConsumerCredits() {
        return consumerCredits;
    }

    public void setConsumerCredits(Long consumerCredits) {
        this.consumerCredits = consumerCredits;
    }

    public Long getConsumeCredits() {
        return consumeCredits;
    }

    public void setConsumeCredits(Long consumeCredits) {
        this.consumeCredits = consumeCredits;
    }

    public String getActivityOptionId() {
        return activityOptionId;
    }

    public void setActivityOptionId(String activityOptionId) {
        this.activityOptionId = activityOptionId;
    }

    public String getActivityOptionName() {
        return activityOptionName;
    }

    public void setActivityOptionName(String activityOptionName) {
        this.activityOptionName = activityOptionName;
    }

    public Integer getAcceptStatus() {
        return acceptStatus;
    }

    public void setAcceptStatus(Integer acceptStatus) {
        this.acceptStatus = acceptStatus;
    }

    public Date getJoinTime() {
        return joinTime;
    }

    public void setJoinTime(Date joinTime) {
        this.joinTime = joinTime;
    }

    public Long getJoinFlowId() {
        return joinFlowId;
    }

    public void setJoinFlowId(Long joinFlowId) {
        this.joinFlowId = joinFlowId;
    }

    public String getTaskName() {
        return taskName;
    }

    public void setTaskName(String taskName) {
        this.taskName = taskName;
    }

    public Long getCompleteTimes() {
        return completeTimes;
    }

    public void setCompleteTimes(Long completeTimes) {
        this.completeTimes = completeTimes;
    }

    public Long getConsumeTimes() {
        return consumeTimes;
    }

    public void setConsumeTimes(Long consumeTimes) {
        this.consumeTimes = consumeTimes;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }
}

==> odps-center-api-1.3.0-20240128.024956-6-sources.jar: cn/com/duiba/odps/center/api/dto/hsbc/DuibaPartnerActJoinDetailNewDTO.java <==
package cn.com.duiba.odps.center.api.dto.hsbc;

import java.io.Serializable;
import java.util.Date;

/**
 * @author: LuHui
 * @date: 2023/10/16 17:57
 * @description:
 */
public class DuibaPartnerActJoinDetailNewDTO implements Serializable {
    private static final long serialVersionUID = 9156092594387363418L;

    /**
     * 自增主键
     */
    private Long id;

    /**
     * 应用ID
     */
    private Long appId;
    /**
     * 兑吧活动id
     */
    private String duibaActivityId;
    /**
     * 开发者活动ID
     */
    private String operatingActivityId;
    /**
     * 开发者活动类型
     */
    private Integer operatingActivityType;
    /**
     * 兑吧活动类型
     */
    private Integer duibaActivityType;
    /**
     * 活动名称
     */
    private String activityName;
    /**
     * 活动开始时间
     */
    private Date activityStartTime;
    /**
     * 活动结束时间
     */
    private Date activityEndTime;
    /**
     * 开发者ID
     */
    private String partnerUserId;
    /**
     * 兑吧用户ID
     */
    private Long consumerId;


    /**
     * 消耗积分数
     */
    private Long consumeCredits;

    /**
     * 中奖奖品id
     */
    private String activityOptionId;

    /**
     * 中奖奖品名称
     */
    private String activityOptionName;
    /**
     * 领奖状态
     */
    private Integer acceptStatus;
    /**
     * 参与时间
     */
    private Date joinTime;
    /**
     * 参与流水ID
     */
    private Long joinFlowId;
    /**
     * 任务名称
     */
    private String taskName;
    /**
     * 完成次数
     */
    private Long completeTimes;
    /**
     * 消费次数
     */
    private Long consumeTimes;

    /**
     * 创建时间
     */
    private Date gmtCreate;

    /**
     * 修改时间
     */
    private Date gmtModified;


    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public String getDuibaActivityId() {
        return duibaActivityId;
    }

    public void setDuibaActivityId(String duibaActivityId) {
        this.duibaActivityId = duibaActivityId;
    }

    public String getOperatingActivityId() {
        return operatingActivityId;
    }

    public void setOperatingActivityId(String operatingActivityId) {
        this.operatingActivityId = operatingActivityId;
    }

    public Integer getOperatingActivityType() {
        return operatingActivityType;
    }

    public void setOperatingActivityType(Integer operatingActivityType) {
        this.operatingActivityType = operatingActivityType;
    }

    public Integer getDuibaActivityType() {
        return duibaActivityType;
    }

    public void setDuibaActivityType(Integer duibaActivityType) {
        this.duibaActivityType = duibaActivityType;
    }

    public String getActivityName() {
        return activityName;
    }

    public void setActivityName(String activityName) {
        this.activityName = activityName;
    }

    public Date getActivityStartTime() {
        return activityStartTime;
    }

    public void setActivityStartTime(Date activityStartTime) {
        this.activityStartTime = activityStartTime;
    }

    public Date getActivityEndTime() {
        return activityEndTime;
    }

    public void setActivityEndTime(Date activityEndTime) {
        this.activityEndTime = activityEndTime;
    }

    public String getPartnerUserId() {
        return partnerUserId;
    }

    public void setPartnerUserId(String partnerUserId) {
        this.partnerUserId = partnerUserId;
    }

    public Long getConsumerId() {
        return consumerId;
    }

    public void setConsumerId(Long consumerId) {
        this.consumerId = consumerId;
    }


    public Long getConsumeCredits() {
        return consumeCredits;
    }

    public void setConsumeCredits(Long consumeCredits) {
        this.consumeCredits = consumeCredits;
    }

    public String getActivityOptionId() {
        return activityOptionId;
    }

    public void setActivityOptionId(String activityOptionId) {
        this.activityOptionId = activityOptionId;
    }

    public String getActivityOptionName() {
        return activityOptionName;
    }

    public void setActivityOptionName(String activityOptionName) {
        this.activityOptionName = activityOptionName;
    }

    public Integer getAcceptStatus() {
        return acceptStatus;
    }

    public void setAcceptStatus(Integer acceptStatus) {
        this.acceptStatus = acceptStatus;
    }

    public Date getJoinTime() {
        return joinTime;
    }

    public void setJoinTime(Date joinTime) {
        this.joinTime = joinTime;
    }

    public Long getJoinFlowId() {
        return joinFlowId;
    }

    public void setJoinFlowId(Long joinFlowId) {
        this.joinFlowId = joinFlowId;
    }

    public String getTaskName() {
        return taskName;
    }

    public void setTaskName(String taskName) {
        this.taskName = taskName;
    }

    public Long getCompleteTimes() {
        return completeTimes;
    }

    public void setCompleteTimes(Long completeTimes) {
        this.completeTimes = completeTimes;
    }

    public Long getConsumeTimes() {
        return consumeTimes;
    }

    public void setConsumeTimes(Long consumeTimes) {
        this.consumeTimes = consumeTimes;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }
}
